@@ -47,6 +47,17 @@ int Repeater(void)
                 	exit(-1);
         	}
         	DB(fprintf(stderr,"setsockopt:OK\n"));
+
+		memcpy (send_msg.trust_name, TrustName, 16);
+		memcpy (send_msg.rep_name, RepeaterCall, 8);
+                send_msg.type = RepActive;
+                send_msg.protocol = G3;
+                dbAddr.sin_family = AF_INET;
+                dbAddr.sin_port = dbOutPort;
+                dbAddr.sin_addr.s_addr = inet_addr("127.0.0.1");
+                ret = sendto (dbSock, (char *)&send_msg, sizeof (struct shm_form), 0,
+                                (struct sockaddr *)&dbAddr, sizeof(dbAddr));
+
 		while(1){
 			readOk = Mask;
 			timeout.tv_sec = 0;
@@ -77,7 +88,7 @@ int Repeater(void)
                                                                 reqConMsg.reqConnect.PacketID[0] = shm_msg->shmem[n].mem.PacketID[0];
                                                                 reqConMsg.reqConnect.PacketID[1] = shm_msg->shmem[n].mem.PacketID[1];
 								reqConMsg.reqConnect.port = shm_msg->shmem[n].mem.srcPort;
-								memcpy (reqConMsg.reqConnect.trustname, ServerName, 16);
+								memcpy (reqConMsg.reqConnect.trustname, TrustName, 16);
 								send(Acc, (char *)&reqConMsg, sizeof(reqConMsg), 0);
 								shm_msg->shmem[n].mem.type = NoEntry;
 							}
@@ -98,7 +109,7 @@ int Repeater(void)
                                                                         reqConMsg.ackConnect.YourCall,
 									ntohs(reqConMsg.ackConnect.port),
                                                                         inet_ntoa(reqConMsg.ackConnect.ip));
-                                                                memcpy (reqConMsg.ackConnect.trustname, ServerName, 16);
+                                                                memcpy (reqConMsg.ackConnect.trustname, TrustName, 16);
                                                                 send (Acc, (char *)&reqConMsg, sizeof(reqConMsg), 0);
                                                                 shm_msg->shmem[n].mem.type = NoEntry;
                                                         }
@@ -119,7 +130,7 @@ int Repeater(void)
                                                                         reqConMsg.ackConnect.YourCall,
                                                                         ntohs(reqConMsg.ackConnect.port),
                                                                         inet_ntoa(reqConMsg.ackConnect.ip));
-                                                                memcpy (reqConMsg.reqConnect.trustname, ServerName, 16);
+                                                                memcpy (reqConMsg.reqConnect.trustname, TrustName, 16);
                                                                 send (Acc, (char *)&reqConMsg, sizeof(reqConMsg), 0);
                                                                 shm_msg->shmem[n].mem.type = NoEntry;
                                                         }
@@ -138,7 +149,7 @@ int Repeater(void)
                                                                         reqConMsg.ackConnect.YourCall,
                                                                         ntohs(reqConMsg.ackConnect.port),
                                                                         inet_ntoa(reqConMsg.ackConnect.ip));
-                                                                memcpy (reqConMsg.ackConnect.trustname, ServerName, 16);
+                                                                memcpy (reqConMsg.ackConnect.trustname, TrustName, 16);
                                                                 send (Acc, (char *)&reqConMsg, sizeof(reqConMsg), 0);
                                                                 shm_msg->shmem[n].mem.type = NoEntry;
                                                         }
