@@ -57,7 +57,7 @@ void	NoRoute(void);
 void	insEntry(void);
 
 char	RepeaterCall[8];
-char	ServerName[16];
+char	TrustName[16];
 struct	in_addr	RepeaterIP;
 struct  sockaddr_in     db_in;
 
